pub async fn flows_executor_get(
configuration: &Configuration,
flow_slug: &str,
query: &str,
) -> Result<ChallengeTypes, Error<FlowsExecutorGetError>>Expand description
Get the next pending challenge from the currently active flow.
pub async fn flows_executor_get(
configuration: &Configuration,
flow_slug: &str,
query: &str,
) -> Result<ChallengeTypes, Error<FlowsExecutorGetError>>Get the next pending challenge from the currently active flow.