Module lifecycle_api

Module lifecycle_api 

Enums

LifecycleIterationsCreateError
struct for typed errors of method lifecycle_iterations_create
LifecycleIterationsLatestRetrieveError
struct for typed errors of method lifecycle_iterations_latest_retrieve
LifecycleIterationsListOpenError
struct for typed errors of method lifecycle_iterations_list_open
LifecycleReviewsCreateError
struct for typed errors of method lifecycle_reviews_create
LifecycleRulesCreateError
struct for typed errors of method lifecycle_rules_create
LifecycleRulesDestroyError
struct for typed errors of method lifecycle_rules_destroy
LifecycleRulesListError
struct for typed errors of method lifecycle_rules_list
LifecycleRulesPartialUpdateError
struct for typed errors of method lifecycle_rules_partial_update
LifecycleRulesRetrieveError
struct for typed errors of method lifecycle_rules_retrieve
LifecycleRulesUpdateError
struct for typed errors of method lifecycle_rules_update

Functions

lifecycle_iterations_create
Mixin to validate that a valid enterprise license exists before allowing to save the object
lifecycle_iterations_latest_retrieve
Mixin to validate that a valid enterprise license exists before allowing to save the object
lifecycle_iterations_list_open
Mixin to validate that a valid enterprise license exists before allowing to save the object
lifecycle_reviews_create
Mixin to validate that a valid enterprise license exists before allowing to save the object
lifecycle_rules_create
lifecycle_rules_destroy
lifecycle_rules_list
lifecycle_rules_partial_update
lifecycle_rules_retrieve
lifecycle_rules_update