pub struct DataExport {
pub id: Uuid,
pub requested_by: PartialUser,
pub requested_on: String,
pub content_type: ContentType,
pub query_params: HashMap<String, Value>,
pub file_url: String,
pub completed: bool,
}Expand description
DataExport : Mixin to validate that a valid enterprise license exists before allowing to save the object
Fields
id: Uuidrequested_by: PartialUserrequested_on: Stringcontent_type: ContentTypequery_params: HashMap<String, Value>file_url: Stringcompleted: boolImplementations
Sourceimpl DataExport
impl DataExport
Sourcepub fn new(
id: Uuid,
requested_by: PartialUser,
requested_on: String,
content_type: ContentType,
query_params: HashMap<String, Value>,
file_url: String,
completed: bool,
) -> DataExport
pub fn new( id: Uuid, requested_by: PartialUser, requested_on: String, content_type: ContentType, query_params: HashMap<String, Value>, file_url: String, completed: bool, ) -> DataExport
Mixin to validate that a valid enterprise license exists before allowing to save the object