pub struct EmailStage {Show 21 fields
pub pk: Uuid,
pub name: String,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub flow_set: Vec<FlowSet>,
pub use_global_settings: Option<bool>,
pub host: Option<String>,
pub port: Option<i32>,
pub username: Option<String>,
pub use_tls: Option<bool>,
pub use_ssl: Option<bool>,
pub timeout: Option<i32>,
pub from_address: Option<String>,
pub token_expiry: Option<String>,
pub subject: Option<String>,
pub template: Option<String>,
pub activate_user_on_success: Option<bool>,
pub recovery_max_attempts: Option<u32>,
pub recovery_cache_timeout: Option<String>,
}Expand description
EmailStage : EmailStage Serializer
Fields
pk: Uuidname: Stringcomponent: StringGet object type so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
flow_set: Vec<FlowSet>use_global_settings: Option<bool>When enabled, global Email connection settings will be used and connection settings below will be ignored.
host: Option<String>port: Option<i32>username: Option<String>use_tls: Option<bool>use_ssl: Option<bool>timeout: Option<i32>from_address: Option<String>token_expiry: Option<String>Time the token sent is valid (Format: hours=3,minutes=17,seconds=300).
subject: Option<String>template: Option<String>activate_user_on_success: Option<bool>Activate users upon completion of stage.
recovery_max_attempts: Option<u32>recovery_cache_timeout: Option<String>The time window used to count recent account recovery attempts. If the number of attempts exceed recovery_max_attempts within this period, further attempts will be rate-limited. (Format: hours=1;minutes=2;seconds=3).
Implementations