EventMatcherPolicy

Struct EventMatcherPolicy 

pub struct EventMatcherPolicy {
    pub pk: Uuid,
    pub name: String,
    pub execution_logging: Option<bool>,
    pub component: String,
    pub verbose_name: String,
    pub verbose_name_plural: String,
    pub meta_model_name: String,
    pub bound_to: i32,
    pub action: Option<Option<EventActions>>,
    pub client_ip: Option<Option<String>>,
    pub app: Option<Option<AppEnum>>,
    pub model: Option<Option<ModelEnum>>,
}
EventMatcherPolicy : Event Matcher Policy Serializer

Fields

pk: Uuidname: Stringexecution_logging: Option<bool>

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.

component: String

Get object component so that we know how to edit the object

verbose_name: String

Return object’s verbose_name

verbose_name_plural: String

Return object’s plural verbose_name

meta_model_name: String

Return internal model name

bound_to: i32

Return objects policy is bound to

action: Option<Option<EventActions>>

Match created events with this action type. When left empty, all action types will be matched.

client_ip: Option<Option<String>>

Matches Event’s Client IP (strict matching, for network matching use an Expression Policy)

app: Option<Option<AppEnum>>

Match events created by selected application. When left empty, all applications are matched.

model: Option<Option<ModelEnum>>

Match events created by selected model. When left empty, all models are matched. When an app is selected, all the application’s models are matched.

Implementations

Source

impl EventMatcherPolicy

pub fn new( pk: Uuid, name: String, component: String, verbose_name: String, verbose_name_plural: String, meta_model_name: String, bound_to: i32, ) -> EventMatcherPolicy

Event Matcher Policy Serializer