EventMatcherPolicyRequest

Struct EventMatcherPolicyRequest 

pub struct EventMatcherPolicyRequest {
    pub name: String,
    pub execution_logging: Option<bool>,
    pub action: Option<Option<EventActions>>,
    pub client_ip: Option<Option<String>>,
    pub app: Option<Option<AppEnum>>,
    pub model: Option<Option<ModelEnum>>,
}
EventMatcherPolicyRequest : Event Matcher Policy Serializer

Fields

name: Stringexecution_logging: Option<bool>

When this option is enabled, all executions of this policy will be logged. By default, only execution errors are logged.

action: Option<Option<EventActions>>

Match created events with this action type. When left empty, all action types will be matched.

client_ip: Option<Option<String>>

Matches Event’s Client IP (strict matching, for network matching use an Expression Policy)

app: Option<Option<AppEnum>>

Match events created by selected application. When left empty, all applications are matched.

model: Option<Option<ModelEnum>>

Match events created by selected model. When left empty, all models are matched. When an app is selected, all the application’s models are matched.

Implementations

Source

impl EventMatcherPolicyRequest

pub fn new(name: String) -> EventMatcherPolicyRequest

Event Matcher Policy Serializer