pub struct Flow {Show 18 fields
pub pk: Uuid,
pub policybindingmodel_ptr_id: Uuid,
pub name: String,
pub slug: String,
pub title: String,
pub designation: FlowDesignationEnum,
pub background: Option<String>,
pub background_url: String,
pub background_themed_urls: Option<ThemedUrls>,
pub stages: Vec<Uuid>,
pub policies: Vec<Uuid>,
pub cache_count: i32,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub compatibility_mode: Option<bool>,
pub export_url: String,
pub layout: Option<FlowLayoutEnum>,
pub denied_action: Option<DeniedActionEnum>,
pub authentication: Option<AuthenticationEnum>,
}Expand description
Flow : Flow Serializer
Fields
pk: Uuidpolicybindingmodel_ptr_id: Uuidname: Stringslug: StringVisible in the URL.
title: StringShown as the Title in Flow pages.
designation: FlowDesignationEnumDecides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.
background: Option<String>Background shown during execution
background_url: StringGet the URL to the background image
background_themed_urls: Option<ThemedUrls>stages: Vec<Uuid>policies: Vec<Uuid>cache_count: i32Get count of cached flows
policy_engine_mode: Option<PolicyEngineMode>compatibility_mode: Option<bool>Enable compatibility mode, increases compatibility with password managers on mobile devices.
export_url: StringGet export URL for flow
layout: Option<FlowLayoutEnum>denied_action: Option<DeniedActionEnum>Configure what should happen when a flow denies access to a user.
authentication: Option<AuthenticationEnum>Required level of authentication and authorization to access a flow.
Implementations
Sourceimpl Flow
impl Flow
Sourcepub fn new(
pk: Uuid,
policybindingmodel_ptr_id: Uuid,
name: String,
slug: String,
title: String,
designation: FlowDesignationEnum,
background_url: String,
background_themed_urls: Option<ThemedUrls>,
stages: Vec<Uuid>,
policies: Vec<Uuid>,
cache_count: i32,
export_url: String,
) -> Flow
pub fn new( pk: Uuid, policybindingmodel_ptr_id: Uuid, name: String, slug: String, title: String, designation: FlowDesignationEnum, background_url: String, background_themed_urls: Option<ThemedUrls>, stages: Vec<Uuid>, policies: Vec<Uuid>, cache_count: i32, export_url: String, ) -> Flow
Flow Serializer