pub struct FlowSet {
pub pk: Uuid,
pub policybindingmodel_ptr_id: Uuid,
pub name: String,
pub slug: String,
pub title: String,
pub designation: FlowDesignationEnum,
pub background_url: String,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub compatibility_mode: Option<bool>,
pub export_url: String,
pub layout: Option<FlowLayoutEnum>,
pub denied_action: Option<DeniedActionEnum>,
}Expand description
FlowSet : Stripped down flow serializer
Fields
pk: Uuidpolicybindingmodel_ptr_id: Uuidname: Stringslug: StringVisible in the URL.
title: StringShown as the Title in Flow pages.
designation: FlowDesignationEnumDecides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.
background_url: StringGet the URL to the background image
policy_engine_mode: Option<PolicyEngineMode>compatibility_mode: Option<bool>Enable compatibility mode, increases compatibility with password managers on mobile devices.
export_url: StringGet export URL for flow
layout: Option<FlowLayoutEnum>denied_action: Option<DeniedActionEnum>Configure what should happen when a flow denies access to a user.
Implementations