pub struct FlowSetRequest {
pub name: String,
pub slug: String,
pub title: String,
pub designation: FlowDesignationEnum,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub compatibility_mode: Option<bool>,
pub layout: Option<FlowLayoutEnum>,
pub denied_action: Option<DeniedActionEnum>,
}Expand description
FlowSetRequest : Stripped down flow serializer
Fields
name: Stringslug: StringVisible in the URL.
title: StringShown as the Title in Flow pages.
designation: FlowDesignationEnumDecides what this Flow is used for. For example, the Authentication flow is redirect to when an un-authenticated user visits authentik.
policy_engine_mode: Option<PolicyEngineMode>compatibility_mode: Option<bool>Enable compatibility mode, increases compatibility with password managers on mobile devices.
layout: Option<FlowLayoutEnum>denied_action: Option<DeniedActionEnum>Configure what should happen when a flow denies access to a user.
Implementations
Sourceimpl FlowSetRequest
impl FlowSetRequest
Sourcepub fn new(
name: String,
slug: String,
title: String,
designation: FlowDesignationEnum,
) -> FlowSetRequest
pub fn new( name: String, slug: String, title: String, designation: FlowDesignationEnum, ) -> FlowSetRequest
Stripped down flow serializer