pub struct IdentificationStage {Show 20 fields
pub pk: Uuid,
pub name: String,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub flow_set: Vec<FlowSet>,
pub user_fields: Option<Vec<UserFieldsEnum>>,
pub password_stage: Option<Option<Uuid>>,
pub captcha_stage: Option<Option<Uuid>>,
pub case_insensitive_matching: Option<bool>,
pub show_matched_user: Option<bool>,
pub enrollment_flow: Option<Option<Uuid>>,
pub recovery_flow: Option<Option<Uuid>>,
pub passwordless_flow: Option<Option<Uuid>>,
pub sources: Option<Vec<Uuid>>,
pub show_source_labels: Option<bool>,
pub pretend_user_exists: Option<bool>,
pub enable_remember_me: Option<bool>,
pub webauthn_stage: Option<Option<Uuid>>,
}Expand description
IdentificationStage : IdentificationStage Serializer
Fields
pk: Uuidname: Stringcomponent: StringGet object type so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
flow_set: Vec<FlowSet>user_fields: Option<Vec<UserFieldsEnum>>Fields of the user object to match against. (Hold shift to select multiple options)
password_stage: Option<Option<Uuid>>When set, shows a password field, instead of showing the password field as separate step.
captcha_stage: Option<Option<Uuid>>When set, adds functionality exactly like a Captcha stage, but baked into the Identification stage.
case_insensitive_matching: Option<bool>When enabled, user fields are matched regardless of their casing.
show_matched_user: Option<bool>When a valid username/email has been entered, and this option is enabled, the user’s username and avatar will be shown. Otherwise, the text that the user entered will be shown
enrollment_flow: Option<Option<Uuid>>Optional enrollment flow, which is linked at the bottom of the page.
recovery_flow: Option<Option<Uuid>>Optional recovery flow, which is linked at the bottom of the page.
passwordless_flow: Option<Option<Uuid>>Optional passwordless flow, which is linked at the bottom of the page.
sources: Option<Vec<Uuid>>Specify which sources should be shown.
show_source_labels: Option<bool>pretend_user_exists: Option<bool>When enabled, the stage will succeed and continue even when incorrect user info is entered.
enable_remember_me: Option<bool>Show the user the ‘Remember me on this device’ toggle, allowing repeat users to skip straight to entering their password.
webauthn_stage: Option<Option<Uuid>>When set, and conditional WebAuthn is available, allow the user to use their passkey as a first factor.
Implementations