pub struct KerberosSource {Show 33 fields
pub pk: Uuid,
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub promoted: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub managed: Option<String>,
pub user_path_template: Option<String>,
pub icon: Option<String>,
pub icon_url: String,
pub icon_themed_urls: Option<ThemedUrls>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub realm: String,
pub krb5_conf: Option<String>,
pub kadmin_type: Option<KadminTypeEnum>,
pub sync_users: Option<bool>,
pub sync_users_password: Option<bool>,
pub sync_principal: Option<String>,
pub sync_ccache: Option<String>,
pub connectivity: Option<HashMap<String, String>>,
pub spnego_server_name: Option<String>,
pub spnego_ccache: Option<String>,
pub password_login_update_internal_password: Option<bool>,
pub sync_outgoing_trigger_mode: Option<SyncOutgoingTriggerModeEnum>,
}Expand description
KerberosSource : Kerberos Source Serializer
Fields
pk: Uuidname: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>promoted: Option<bool>When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>component: StringGet object component so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
managed: Option<String>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
user_path_template: Option<String>icon: Option<String>icon_url: Stringicon_themed_urls: Option<ThemedUrls>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
realm: StringKerberos realm
krb5_conf: Option<String>Custom krb5.conf to use. Uses the system one by default
kadmin_type: Option<KadminTypeEnum>KAdmin server type
sync_users: Option<bool>Sync users from Kerberos into authentik
sync_users_password: Option<bool>When a user changes their password, sync it back to Kerberos
sync_principal: Option<String>Principal to authenticate to kadmin for sync.
sync_ccache: Option<String>Credentials cache to authenticate to kadmin for sync. Must be in the form TYPE:residual
connectivity: Option<HashMap<String, String>>Get cached source connectivity
spnego_server_name: Option<String>Force the use of a specific server name for SPNEGO. Must be in the form HTTP@hostname
spnego_ccache: Option<String>Credential cache to use for SPNEGO in form type:residual
password_login_update_internal_password: Option<bool>If enabled, the authentik-stored password will be updated upon login with the Kerberos password backend
sync_outgoing_trigger_mode: Option<SyncOutgoingTriggerModeEnum>When to trigger sync for outgoing providers
Implementations
Sourceimpl KerberosSource
impl KerberosSource
Sourcepub fn new(
pk: Uuid,
name: String,
slug: String,
component: String,
verbose_name: String,
verbose_name_plural: String,
meta_model_name: String,
managed: Option<String>,
icon_url: String,
icon_themed_urls: Option<ThemedUrls>,
realm: String,
connectivity: Option<HashMap<String, String>>,
) -> KerberosSource
pub fn new( pk: Uuid, name: String, slug: String, component: String, verbose_name: String, verbose_name_plural: String, meta_model_name: String, managed: Option<String>, icon_url: String, icon_themed_urls: Option<ThemedUrls>, realm: String, connectivity: Option<HashMap<String, String>>, ) -> KerberosSource
Kerberos Source Serializer