pub struct KerberosSourceRequest {Show 24 fields
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub realm: String,
pub krb5_conf: Option<String>,
pub kadmin_type: Option<KadminTypeEnum>,
pub sync_users: Option<bool>,
pub sync_users_password: Option<bool>,
pub sync_principal: Option<String>,
pub sync_password: Option<String>,
pub sync_keytab: Option<String>,
pub sync_ccache: Option<String>,
pub spnego_server_name: Option<String>,
pub spnego_keytab: Option<String>,
pub spnego_ccache: Option<String>,
pub password_login_update_internal_password: Option<bool>,
}Expand description
KerberosSourceRequest : Kerberos Source Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
user_path_template: Option<String>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
realm: StringKerberos realm
krb5_conf: Option<String>Custom krb5.conf to use. Uses the system one by default
kadmin_type: Option<KadminTypeEnum>KAdmin server type
sync_users: Option<bool>Sync users from Kerberos into authentik
sync_users_password: Option<bool>When a user changes their password, sync it back to Kerberos
sync_principal: Option<String>Principal to authenticate to kadmin for sync.
sync_password: Option<String>Password to authenticate to kadmin for sync
sync_keytab: Option<String>Keytab to authenticate to kadmin for sync. Must be base64-encoded or in the form TYPE:residual
sync_ccache: Option<String>Credentials cache to authenticate to kadmin for sync. Must be in the form TYPE:residual
spnego_server_name: Option<String>Force the use of a specific server name for SPNEGO. Must be in the form HTTP@hostname
spnego_keytab: Option<String>SPNEGO keytab base64-encoded or path to keytab in the form FILE:path
spnego_ccache: Option<String>Credential cache to use for SPNEGO in form type:residual
password_login_update_internal_password: Option<bool>If enabled, the authentik-stored password will be updated upon login with the Kerberos password backend
Implementations