pub struct LdapSourcePropertyMappingRequest {
pub managed: Option<Option<String>>,
pub name: String,
pub expression: String,
}Expand description
LdapSourcePropertyMappingRequest : LDAP PropertyMapping Serializer
Fields
managed: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Stringexpression: StringImplementations
Sourceimpl LdapSourcePropertyMappingRequest
impl LdapSourcePropertyMappingRequest
Sourcepub fn new(name: String, expression: String) -> LdapSourcePropertyMappingRequest
pub fn new(name: String, expression: String) -> LdapSourcePropertyMappingRequest
LDAP PropertyMapping Serializer