pub struct LifecycleIteration {Show 14 fields
pub id: Uuid,
pub content_type: ContentTypeEnum,
pub object_id: String,
pub object_verbose: String,
pub object_admin_url: String,
pub state: LifecycleIterationStateEnum,
pub opened_on: String,
pub grace_period_end: String,
pub next_review_date: String,
pub reviews: Vec<Review>,
pub user_can_review: bool,
pub reviewer_groups: Vec<ReviewerGroup>,
pub min_reviewers: i32,
pub reviewers: Vec<ReviewerUser>,
}Expand description
LifecycleIteration : Mixin to validate that a valid enterprise license exists before allowing to save the object
Fields
id: Uuidcontent_type: ContentTypeEnumobject_id: Stringobject_verbose: Stringobject_admin_url: Stringstate: LifecycleIterationStateEnumopened_on: Stringgrace_period_end: Stringnext_review_date: Stringreviews: Vec<Review>user_can_review: boolreviewer_groups: Vec<ReviewerGroup>min_reviewers: i32reviewers: Vec<ReviewerUser>Implementations
Sourceimpl LifecycleIteration
impl LifecycleIteration
Sourcepub fn new(
id: Uuid,
content_type: ContentTypeEnum,
object_id: String,
object_verbose: String,
object_admin_url: String,
state: LifecycleIterationStateEnum,
opened_on: String,
grace_period_end: String,
next_review_date: String,
reviews: Vec<Review>,
user_can_review: bool,
reviewer_groups: Vec<ReviewerGroup>,
min_reviewers: i32,
reviewers: Vec<ReviewerUser>,
) -> LifecycleIteration
pub fn new( id: Uuid, content_type: ContentTypeEnum, object_id: String, object_verbose: String, object_admin_url: String, state: LifecycleIterationStateEnum, opened_on: String, grace_period_end: String, next_review_date: String, reviews: Vec<Review>, user_can_review: bool, reviewer_groups: Vec<ReviewerGroup>, min_reviewers: i32, reviewers: Vec<ReviewerUser>, ) -> LifecycleIteration
Mixin to validate that a valid enterprise license exists before allowing to save the object