pub struct LifecycleIterationRequest {
pub content_type: ContentTypeEnum,
}Expand description
LifecycleIterationRequest : Mixin to validate that a valid enterprise license exists before allowing to save the object
Fields
content_type: ContentTypeEnumImplementations
Sourceimpl LifecycleIterationRequest
impl LifecycleIterationRequest
Sourcepub fn new(content_type: ContentTypeEnum) -> LifecycleIterationRequest
pub fn new(content_type: ContentTypeEnum) -> LifecycleIterationRequest
Mixin to validate that a valid enterprise license exists before allowing to save the object