pub struct MicrosoftEntraProviderMapping {
pub pk: Uuid,
pub managed: Option<Option<String>>,
pub name: String,
pub expression: String,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
}Expand description
MicrosoftEntraProviderMapping : MicrosoftEntraProviderMapping Serializer
Fields
pk: Uuidmanaged: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Stringexpression: Stringcomponent: StringGet object’s component so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
Implementations