pub struct NotificationRule {
pub pk: Uuid,
pub name: String,
pub transports: Option<Vec<Uuid>>,
pub severity: Option<SeverityEnum>,
pub destination_group: Option<Option<Uuid>>,
pub destination_group_obj: Group,
pub destination_event_user: Option<bool>,
}Expand description
NotificationRule : NotificationRule Serializer
Fields
pk: Uuidname: Stringtransports: Option<Vec<Uuid>>Select which transports should be used to notify the user. If none are selected, the notification will only be shown in the authentik UI.
severity: Option<SeverityEnum>Controls which severity level the created notifications will have.
destination_group: Option<Option<Uuid>>Define which group of users this notification should be sent and shown to. If left empty, Notification won’t ben sent.
destination_group_obj: Groupdestination_event_user: Option<bool>When enabled, notification will be sent to user the user that triggered the event.When destination_group is configured, notification is sent to both.
Implementations