pub struct OAuthSource {Show 35 fields
pub pk: Uuid,
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub promoted: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub managed: Option<String>,
pub user_path_template: Option<String>,
pub icon: Option<String>,
pub icon_url: Option<String>,
pub icon_themed_urls: Option<ThemedUrls>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub provider_type: ProviderTypeEnum,
pub request_token_url: Option<Option<String>>,
pub authorization_url: Option<Option<String>>,
pub access_token_url: Option<Option<String>>,
pub profile_url: Option<Option<String>>,
pub pkce: Option<PkceMethodEnum>,
pub consumer_key: String,
pub callback_url: String,
pub additional_scopes: Option<String>,
pub type: SourceType,
pub oidc_well_known_url: Option<String>,
pub oidc_jwks_url: Option<String>,
pub oidc_jwks: Option<HashMap<String, Value>>,
pub authorization_code_auth_method: Option<AuthorizationCodeAuthMethodEnum>,
}Expand description
OAuthSource : OAuth Source Serializer
Fields
pk: Uuidname: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>promoted: Option<bool>When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>component: StringGet object component so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
managed: Option<String>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
user_path_template: Option<String>icon: Option<String>icon_url: Option<String>icon_themed_urls: Option<ThemedUrls>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
provider_type: ProviderTypeEnumrequest_token_url: Option<Option<String>>URL used to request the initial token. This URL is only required for OAuth 1.
URL the user is redirect to to conest the flow.
access_token_url: Option<Option<String>>URL used by authentik to retrieve tokens.
profile_url: Option<Option<String>>URL used by authentik to get user information.
pkce: Option<PkceMethodEnum>consumer_key: Stringcallback_url: StringGet OAuth Callback URL
additional_scopes: Option<String>type: SourceTypeoidc_well_known_url: Option<String>oidc_jwks_url: Option<String>oidc_jwks: Option<HashMap<String, Value>>How to perform authentication during an authorization_code token request flow
Implementations
Sourceimpl OAuthSource
impl OAuthSource
Sourcepub fn new(
pk: Uuid,
name: String,
slug: String,
component: String,
verbose_name: String,
verbose_name_plural: String,
meta_model_name: String,
managed: Option<String>,
icon_url: Option<String>,
icon_themed_urls: Option<ThemedUrls>,
provider_type: ProviderTypeEnum,
consumer_key: String,
callback_url: String,
type: SourceType,
) -> OAuthSource
pub fn new( pk: Uuid, name: String, slug: String, component: String, verbose_name: String, verbose_name_plural: String, meta_model_name: String, managed: Option<String>, icon_url: Option<String>, icon_themed_urls: Option<ThemedUrls>, provider_type: ProviderTypeEnum, consumer_key: String, callback_url: String, type: SourceType, ) -> OAuthSource
OAuth Source Serializer