pub struct OAuthSourcePropertyMappingRequest {
pub managed: Option<Option<String>>,
pub name: String,
pub expression: String,
}Expand description
OAuthSourcePropertyMappingRequest : OAuthSourcePropertyMapping Serializer
Fields
managed: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Stringexpression: StringImplementations
Sourceimpl OAuthSourcePropertyMappingRequest
impl OAuthSourcePropertyMappingRequest
Sourcepub fn new(
name: String,
expression: String,
) -> OAuthSourcePropertyMappingRequest
pub fn new( name: String, expression: String, ) -> OAuthSourcePropertyMappingRequest
OAuthSourcePropertyMapping Serializer