pub struct OAuthSourceRequest {Show 26 fields
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub promoted: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub icon: Option<String>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub provider_type: ProviderTypeEnum,
pub request_token_url: Option<Option<String>>,
pub authorization_url: Option<Option<String>>,
pub access_token_url: Option<Option<String>>,
pub profile_url: Option<Option<String>>,
pub pkce: Option<PkceMethodEnum>,
pub consumer_key: String,
pub consumer_secret: String,
pub additional_scopes: Option<String>,
pub oidc_well_known_url: Option<String>,
pub oidc_jwks_url: Option<String>,
pub oidc_jwks: Option<HashMap<String, Value>>,
pub authorization_code_auth_method: Option<AuthorizationCodeAuthMethodEnum>,
}Expand description
OAuthSourceRequest : OAuth Source Serializer
Fields
name: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>promoted: Option<bool>When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
user_path_template: Option<String>icon: Option<String>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
provider_type: ProviderTypeEnumrequest_token_url: Option<Option<String>>URL used to request the initial token. This URL is only required for OAuth 1.
URL the user is redirect to to conest the flow.
access_token_url: Option<Option<String>>URL used by authentik to retrieve tokens.
profile_url: Option<Option<String>>URL used by authentik to get user information.
pkce: Option<PkceMethodEnum>consumer_key: Stringconsumer_secret: Stringadditional_scopes: Option<String>oidc_well_known_url: Option<String>oidc_jwks_url: Option<String>oidc_jwks: Option<HashMap<String, Value>>How to perform authentication during an authorization_code token request flow
Implementations
Sourceimpl OAuthSourceRequest
impl OAuthSourceRequest
Sourcepub fn new(
name: String,
slug: String,
provider_type: ProviderTypeEnum,
consumer_key: String,
consumer_secret: String,
) -> OAuthSourceRequest
pub fn new( name: String, slug: String, provider_type: ProviderTypeEnum, consumer_key: String, consumer_secret: String, ) -> OAuthSourceRequest
OAuth Source Serializer