pub struct PatchedGoogleWorkspaceProviderRequest {Show 14 fields
pub name: Option<String>,
pub property_mappings: Option<Vec<Uuid>>,
pub property_mappings_group: Option<Vec<Uuid>>,
pub delegated_subject: Option<String>,
pub credentials: Option<HashMap<String, Value>>,
pub scopes: Option<String>,
pub exclude_users_service_account: Option<bool>,
pub filter_group: Option<Option<Uuid>>,
pub user_delete_action: Option<OutgoingSyncDeleteAction>,
pub group_delete_action: Option<OutgoingSyncDeleteAction>,
pub default_group_email_domain: Option<String>,
pub sync_page_size: Option<u32>,
pub sync_page_timeout: Option<String>,
pub dry_run: Option<bool>,
}Expand description
PatchedGoogleWorkspaceProviderRequest : GoogleWorkspaceProvider Serializer
Fields
name: Option<String>property_mappings: Option<Vec<Uuid>>property_mappings_group: Option<Vec<Uuid>>Property mappings used for group creation/updating.
delegated_subject: Option<String>credentials: Option<HashMap<String, Value>>scopes: Option<String>exclude_users_service_account: Option<bool>filter_group: Option<Option<Uuid>>user_delete_action: Option<OutgoingSyncDeleteAction>group_delete_action: Option<OutgoingSyncDeleteAction>default_group_email_domain: Option<String>sync_page_size: Option<u32>Controls the number of objects synced in a single task
sync_page_timeout: Option<String>Timeout for synchronization of a single page
dry_run: Option<bool>When enabled, provider will not modify or create objects in the remote system.
Implementations
Sourceimpl PatchedGoogleWorkspaceProviderRequest
impl PatchedGoogleWorkspaceProviderRequest
Sourcepub fn new() -> PatchedGoogleWorkspaceProviderRequest
pub fn new() -> PatchedGoogleWorkspaceProviderRequest
GoogleWorkspaceProvider Serializer