pub struct PatchedLifecycleRuleRequest {
pub name: Option<String>,
pub content_type: Option<ContentTypeEnum>,
pub object_id: Option<Option<String>>,
pub interval: Option<String>,
pub grace_period: Option<String>,
pub reviewer_groups: Option<Vec<Uuid>>,
pub min_reviewers: Option<u16>,
pub min_reviewers_is_per_group: Option<bool>,
pub reviewers: Option<Vec<Uuid>>,
pub notification_transports: Option<Vec<Uuid>>,
}Expand description
PatchedLifecycleRuleRequest : Mixin to validate that a valid enterprise license exists before allowing to save the object
Fields
name: Option<String>content_type: Option<ContentTypeEnum>object_id: Option<Option<String>>interval: Option<String>grace_period: Option<String>reviewer_groups: Option<Vec<Uuid>>min_reviewers: Option<u16>min_reviewers_is_per_group: Option<bool>reviewers: Option<Vec<Uuid>>notification_transports: Option<Vec<Uuid>>Select which transports should be used to notify the reviewers. If none are selected, the notification will only be shown in the authentik UI.
Implementations
Sourceimpl PatchedLifecycleRuleRequest
impl PatchedLifecycleRuleRequest
Sourcepub fn new() -> PatchedLifecycleRuleRequest
pub fn new() -> PatchedLifecycleRuleRequest
Mixin to validate that a valid enterprise license exists before allowing to save the object