pub struct PatchedPlexSourceRequest {Show 17 fields
pub name: Option<String>,
pub slug: Option<String>,
pub enabled: Option<bool>,
pub promoted: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub user_path_template: Option<String>,
pub icon: Option<String>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub client_id: Option<String>,
pub allowed_servers: Option<Vec<String>>,
pub allow_friends: Option<bool>,
pub plex_token: Option<String>,
}Expand description
PatchedPlexSourceRequest : Plex Source Serializer
Fields
name: Option<String>Source’s display Name.
slug: Option<String>Internal source name, used in URLs.
enabled: Option<bool>promoted: Option<bool>When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
user_path_template: Option<String>icon: Option<String>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
client_id: Option<String>Client identifier used to talk to Plex.
allowed_servers: Option<Vec<String>>Which servers a user has to be a member of to be granted access. Empty list allows every server.
allow_friends: Option<bool>Allow friends to authenticate, even if you don’t share a server.
plex_token: Option<String>Plex token used to check friends
Implementations
Sourceimpl PatchedPlexSourceRequest
impl PatchedPlexSourceRequest
Sourcepub fn new() -> PatchedPlexSourceRequest
pub fn new() -> PatchedPlexSourceRequest
Plex Source Serializer