pub struct PatchedSamlProviderRequest {Show 27 fields
pub name: Option<String>,
pub authentication_flow: Option<Option<Uuid>>,
pub authorization_flow: Option<Uuid>,
pub invalidation_flow: Option<Uuid>,
pub property_mappings: Option<Vec<Uuid>>,
pub acs_url: Option<String>,
pub sls_url: Option<String>,
pub audience: Option<String>,
pub issuer: Option<String>,
pub assertion_valid_not_before: Option<String>,
pub assertion_valid_not_on_or_after: Option<String>,
pub session_valid_not_on_or_after: Option<String>,
pub name_id_mapping: Option<Option<Uuid>>,
pub authn_context_class_ref_mapping: Option<Option<Uuid>>,
pub digest_algorithm: Option<DigestAlgorithmEnum>,
pub signature_algorithm: Option<SignatureAlgorithmEnum>,
pub signing_kp: Option<Option<Uuid>>,
pub verification_kp: Option<Option<Uuid>>,
pub encryption_kp: Option<Option<Uuid>>,
pub sign_assertion: Option<bool>,
pub sign_response: Option<bool>,
pub sign_logout_request: Option<bool>,
pub sp_binding: Option<SamlBindingsEnum>,
pub sls_binding: Option<SamlBindingsEnum>,
pub logout_method: Option<SamlLogoutMethods>,
pub default_relay_state: Option<String>,
pub default_name_id_policy: Option<SamlNameIdPolicyEnum>,
}Expand description
PatchedSamlProviderRequest : SAMLProvider Serializer
Fields
name: Option<String>authentication_flow: Option<Option<Uuid>>Flow used for authentication when the associated application is accessed by an un-authenticated user.
Flow used when authorizing this provider.
invalidation_flow: Option<Uuid>Flow used ending the session from a provider.
property_mappings: Option<Vec<Uuid>>acs_url: Option<String>sls_url: Option<String>Single Logout Service URL where the logout response should be sent.
audience: Option<String>Value of the audience restriction field of the assertion. When left empty, no audience restriction will be added.
issuer: Option<String>Also known as EntityID
assertion_valid_not_before: Option<String>Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
assertion_valid_not_on_or_after: Option<String>Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
session_valid_not_on_or_after: Option<String>Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
name_id_mapping: Option<Option<Uuid>>Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered
authn_context_class_ref_mapping: Option<Option<Uuid>>Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.
digest_algorithm: Option<DigestAlgorithmEnum>signature_algorithm: Option<SignatureAlgorithmEnum>signing_kp: Option<Option<Uuid>>Keypair used to sign outgoing Responses going to the Service Provider.
verification_kp: Option<Option<Uuid>>When selected, incoming assertion’s Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.
encryption_kp: Option<Option<Uuid>>When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.
sign_assertion: Option<bool>sign_response: Option<bool>sign_logout_request: Option<bool>sp_binding: Option<SamlBindingsEnum>This determines how authentik sends the response back to the Service Provider.
sls_binding: Option<SamlBindingsEnum>This determines how authentik sends the logout response back to the Service Provider.
logout_method: Option<SamlLogoutMethods>Method to use for logout. Front-channel iframe loads all logout URLs simultaneously in hidden iframes. Front-channel native uses your active browser tab to send post requests and redirect to providers. Back-channel sends logout requests directly from the server without user interaction (requires POST SLS binding).
default_relay_state: Option<String>Default relay_state value for IDP-initiated logins
default_name_id_policy: Option<SamlNameIdPolicyEnum>Implementations
Sourceimpl PatchedSamlProviderRequest
impl PatchedSamlProviderRequest
Sourcepub fn new() -> PatchedSamlProviderRequest
pub fn new() -> PatchedSamlProviderRequest
SAMLProvider Serializer