pub struct PatchedTelegramSourcePropertyMappingRequest {
pub managed: Option<Option<String>>,
pub name: Option<String>,
pub expression: Option<String>,
}Expand description
PatchedTelegramSourcePropertyMappingRequest : TelegramSourcePropertyMapping Serializer
Fields
managed: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Option<String>expression: Option<String>Implementations
Sourceimpl PatchedTelegramSourcePropertyMappingRequest
impl PatchedTelegramSourcePropertyMappingRequest
Sourcepub fn new() -> PatchedTelegramSourcePropertyMappingRequest
pub fn new() -> PatchedTelegramSourcePropertyMappingRequest
TelegramSourcePropertyMapping Serializer