pub struct PlexSource {Show 25 fields
pub pk: Uuid,
pub name: String,
pub slug: String,
pub enabled: Option<bool>,
pub promoted: Option<bool>,
pub authentication_flow: Option<Option<Uuid>>,
pub enrollment_flow: Option<Option<Uuid>>,
pub user_property_mappings: Option<Vec<Uuid>>,
pub group_property_mappings: Option<Vec<Uuid>>,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub policy_engine_mode: Option<PolicyEngineMode>,
pub user_matching_mode: Option<UserMatchingModeEnum>,
pub managed: Option<String>,
pub user_path_template: Option<String>,
pub icon: Option<String>,
pub icon_url: String,
pub icon_themed_urls: Option<ThemedUrls>,
pub group_matching_mode: Option<GroupMatchingModeEnum>,
pub client_id: Option<String>,
pub allowed_servers: Option<Vec<String>>,
pub allow_friends: Option<bool>,
pub plex_token: String,
}Expand description
PlexSource : Plex Source Serializer
Fields
pk: Uuidname: StringSource’s display Name.
slug: StringInternal source name, used in URLs.
enabled: Option<bool>promoted: Option<bool>When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.
authentication_flow: Option<Option<Uuid>>Flow to use when authenticating existing users.
enrollment_flow: Option<Option<Uuid>>Flow to use when enrolling new users.
user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>component: StringGet object component so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>How the source determines if an existing user should be authenticated or a new user enrolled.
managed: Option<String>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
user_path_template: Option<String>icon: Option<String>icon_url: Stringicon_themed_urls: Option<ThemedUrls>group_matching_mode: Option<GroupMatchingModeEnum>How the source determines if an existing group should be used or a new group created.
client_id: Option<String>Client identifier used to talk to Plex.
allowed_servers: Option<Vec<String>>Which servers a user has to be a member of to be granted access. Empty list allows every server.
allow_friends: Option<bool>Allow friends to authenticate, even if you don’t share a server.
plex_token: StringPlex token used to check friends
Implementations
Sourceimpl PlexSource
impl PlexSource