ProxyProvider

Struct ProxyProvider 

pub struct ProxyProvider {
Show 32 fields pub pk: i32, pub name: String, pub authentication_flow: Option<Option<Uuid>>, pub authorization_flow: Uuid, pub invalidation_flow: Uuid, pub property_mappings: Option<Vec<Uuid>>, pub component: String, pub assigned_application_slug: Option<String>, pub assigned_application_name: Option<String>, pub assigned_backchannel_application_slug: Option<String>, pub assigned_backchannel_application_name: Option<String>, pub verbose_name: String, pub verbose_name_plural: String, pub meta_model_name: String, pub client_id: String, pub internal_host: Option<String>, pub external_host: String, pub internal_host_ssl_validation: Option<bool>, pub certificate: Option<Option<Uuid>>, pub skip_path_regex: Option<String>, pub basic_auth_enabled: Option<bool>, pub basic_auth_password_attribute: Option<String>, pub basic_auth_user_attribute: Option<String>, pub mode: Option<ProxyMode>, pub intercept_header_auth: Option<bool>, pub redirect_uris: Vec<RedirectUri>, pub cookie_domain: Option<String>, pub jwt_federation_sources: Option<Vec<Uuid>>, pub jwt_federation_providers: Option<Vec<i32>>, pub access_token_validity: Option<String>, pub refresh_token_validity: Option<String>, pub outpost_set: Vec<String>,
}
ProxyProvider : ProxyProvider Serializer

Fields

pk: i32name: Stringauthentication_flow: Option<Option<Uuid>>

Flow used for authentication when the associated application is accessed by an un-authenticated user.

authorization_flow: Uuid

Flow used when authorizing this provider.

invalidation_flow: Uuid

Flow used ending the session from a provider.

property_mappings: Option<Vec<Uuid>>component: String

Get object component so that we know how to edit the object

assigned_application_slug: Option<String>

Internal application name, used in URLs.

assigned_application_name: Option<String>

Application’s display Name.

assigned_backchannel_application_slug: Option<String>

Internal application name, used in URLs.

assigned_backchannel_application_name: Option<String>

Application’s display Name.

verbose_name: String

Return object’s verbose_name

verbose_name_plural: String

Return object’s plural verbose_name

meta_model_name: String

Return internal model name

client_id: Stringinternal_host: Option<String>external_host: Stringinternal_host_ssl_validation: Option<bool>

Validate SSL Certificates of upstream servers

certificate: Option<Option<Uuid>>skip_path_regex: Option<String>

Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.

basic_auth_enabled: Option<bool>

Set a custom HTTP-Basic Authentication header based on values from authentik.

basic_auth_password_attribute: Option<String>

User/Group Attribute used for the password part of the HTTP-Basic Header.

basic_auth_user_attribute: Option<String>

User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user’s Email address is used.

mode: Option<ProxyMode>

Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.

intercept_header_auth: Option<bool>

When enabled, this provider will intercept the authorization header and authenticate requests based on its value.

redirect_uris: Vec<RedirectUri>cookie_domain: Option<String>jwt_federation_sources: Option<Vec<Uuid>>jwt_federation_providers: Option<Vec<i32>>access_token_validity: Option<String>

Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).

refresh_token_validity: Option<String>

Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).

outpost_set: Vec<String>

Implementations

Source

impl ProxyProvider

pub fn new( pk: i32, name: String, authorization_flow: Uuid, invalidation_flow: Uuid, component: String, assigned_application_slug: Option<String>, assigned_application_name: Option<String>, assigned_backchannel_application_slug: Option<String>, assigned_backchannel_application_name: Option<String>, verbose_name: String, verbose_name_plural: String, meta_model_name: String, client_id: String, external_host: String, redirect_uris: Vec<RedirectUri>, outpost_set: Vec<String>, ) -> ProxyProvider

ProxyProvider Serializer