pub struct ProxyProviderRequest {Show 20 fields
pub name: String,
pub authentication_flow: Option<Option<Uuid>>,
pub authorization_flow: Uuid,
pub invalidation_flow: Uuid,
pub property_mappings: Option<Vec<Uuid>>,
pub internal_host: Option<String>,
pub external_host: String,
pub internal_host_ssl_validation: Option<bool>,
pub certificate: Option<Option<Uuid>>,
pub skip_path_regex: Option<String>,
pub basic_auth_enabled: Option<bool>,
pub basic_auth_password_attribute: Option<String>,
pub basic_auth_user_attribute: Option<String>,
pub mode: Option<ProxyMode>,
pub intercept_header_auth: Option<bool>,
pub cookie_domain: Option<String>,
pub jwt_federation_sources: Option<Vec<Uuid>>,
pub jwt_federation_providers: Option<Vec<i32>>,
pub access_token_validity: Option<String>,
pub refresh_token_validity: Option<String>,
}Expand description
ProxyProviderRequest : ProxyProvider Serializer
Fields
name: Stringauthentication_flow: Option<Option<Uuid>>Flow used for authentication when the associated application is accessed by an un-authenticated user.
Flow used when authorizing this provider.
invalidation_flow: UuidFlow used ending the session from a provider.
property_mappings: Option<Vec<Uuid>>internal_host: Option<String>external_host: Stringinternal_host_ssl_validation: Option<bool>Validate SSL Certificates of upstream servers
certificate: Option<Option<Uuid>>skip_path_regex: Option<String>Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.
basic_auth_enabled: Option<bool>Set a custom HTTP-Basic Authentication header based on values from authentik.
basic_auth_password_attribute: Option<String>User/Group Attribute used for the password part of the HTTP-Basic Header.
basic_auth_user_attribute: Option<String>User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user’s Email address is used.
mode: Option<ProxyMode>Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.
intercept_header_auth: Option<bool>When enabled, this provider will intercept the authorization header and authenticate requests based on its value.
jwt_federation_sources: Option<Vec<Uuid>>jwt_federation_providers: Option<Vec<i32>>access_token_validity: Option<String>Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
refresh_token_validity: Option<String>Tokens not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
Implementations