pub struct RadiusOutpostConfig {
pub pk: i32,
pub name: String,
pub application_slug: String,
pub auth_flow_slug: String,
pub client_networks: Option<String>,
pub shared_secret: Option<String>,
pub mfa_support: Option<bool>,
pub certificate: Option<Option<Uuid>>,
}Expand description
RadiusOutpostConfig : RadiusProvider Serializer
Fields
pk: i32name: Stringapplication_slug: Stringauth_flow_slug: Stringclient_networks: Option<String>List of CIDRs (comma-separated) that clients can connect from. A more specific CIDR will match before a looser one. Clients connecting from a non-specified CIDR will be dropped.
Shared secret between clients and server to hash packets.
mfa_support: Option<bool>When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.
certificate: Option<Option<Uuid>>Implementations