pub struct RadiusProvider {Show 19 fields
pub pk: i32,
pub name: String,
pub authentication_flow: Option<Option<Uuid>>,
pub authorization_flow: Uuid,
pub invalidation_flow: Uuid,
pub property_mappings: Option<Vec<Uuid>>,
pub component: String,
pub assigned_application_slug: Option<String>,
pub assigned_application_name: Option<String>,
pub assigned_backchannel_application_slug: Option<String>,
pub assigned_backchannel_application_name: Option<String>,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub client_networks: Option<String>,
pub shared_secret: Option<String>,
pub outpost_set: Vec<String>,
pub mfa_support: Option<bool>,
pub certificate: Option<Option<Uuid>>,
}Expand description
RadiusProvider : RadiusProvider Serializer
Fields
pk: i32name: Stringauthentication_flow: Option<Option<Uuid>>Flow used for authentication when the associated application is accessed by an un-authenticated user.
Flow used when authorizing this provider.
invalidation_flow: UuidFlow used ending the session from a provider.
property_mappings: Option<Vec<Uuid>>component: StringGet object component so that we know how to edit the object
assigned_application_slug: Option<String>Internal application name, used in URLs.
assigned_application_name: Option<String>Application’s display Name.
assigned_backchannel_application_slug: Option<String>Internal application name, used in URLs.
assigned_backchannel_application_name: Option<String>Application’s display Name.
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
client_networks: Option<String>List of CIDRs (comma-separated) that clients can connect from. A more specific CIDR will match before a looser one. Clients connecting from a non-specified CIDR will be dropped.
Shared secret between clients and server to hash packets.
outpost_set: Vec<String>mfa_support: Option<bool>When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.
certificate: Option<Option<Uuid>>Implementations
Sourceimpl RadiusProvider
impl RadiusProvider
Sourcepub fn new(
pk: i32,
name: String,
authorization_flow: Uuid,
invalidation_flow: Uuid,
component: String,
assigned_application_slug: Option<String>,
assigned_application_name: Option<String>,
assigned_backchannel_application_slug: Option<String>,
assigned_backchannel_application_name: Option<String>,
verbose_name: String,
verbose_name_plural: String,
meta_model_name: String,
outpost_set: Vec<String>,
) -> RadiusProvider
pub fn new( pk: i32, name: String, authorization_flow: Uuid, invalidation_flow: Uuid, component: String, assigned_application_slug: Option<String>, assigned_application_name: Option<String>, assigned_backchannel_application_slug: Option<String>, assigned_backchannel_application_name: Option<String>, verbose_name: String, verbose_name_plural: String, meta_model_name: String, outpost_set: Vec<String>, ) -> RadiusProvider
RadiusProvider Serializer