pub struct RadiusProviderRequest {
pub name: String,
pub authentication_flow: Option<Option<Uuid>>,
pub authorization_flow: Uuid,
pub invalidation_flow: Uuid,
pub property_mappings: Option<Vec<Uuid>>,
pub client_networks: Option<String>,
pub shared_secret: Option<String>,
pub mfa_support: Option<bool>,
pub certificate: Option<Option<Uuid>>,
}Expand description
RadiusProviderRequest : RadiusProvider Serializer
Fields
name: Stringauthentication_flow: Option<Option<Uuid>>Flow used for authentication when the associated application is accessed by an un-authenticated user.
Flow used when authorizing this provider.
invalidation_flow: UuidFlow used ending the session from a provider.
property_mappings: Option<Vec<Uuid>>client_networks: Option<String>List of CIDRs (comma-separated) that clients can connect from. A more specific CIDR will match before a looser one. Clients connecting from a non-specified CIDR will be dropped.
Shared secret between clients and server to hash packets.
mfa_support: Option<bool>When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon.
certificate: Option<Option<Uuid>>Implementations