SamlSource

Struct SamlSource 

pub struct SamlSource {
Show 36 fields pub pk: Uuid, pub name: String, pub slug: String, pub enabled: Option<bool>, pub promoted: Option<bool>, pub authentication_flow: Option<Option<Uuid>>, pub enrollment_flow: Option<Option<Uuid>>, pub user_property_mappings: Option<Vec<Uuid>>, pub group_property_mappings: Option<Vec<Uuid>>, pub component: String, pub verbose_name: String, pub verbose_name_plural: String, pub meta_model_name: String, pub policy_engine_mode: Option<PolicyEngineMode>, pub user_matching_mode: Option<UserMatchingModeEnum>, pub managed: Option<String>, pub user_path_template: Option<String>, pub icon: Option<String>, pub icon_url: String, pub icon_themed_urls: Option<ThemedUrls>, pub group_matching_mode: Option<GroupMatchingModeEnum>, pub pre_authentication_flow: Uuid, pub issuer: Option<String>, pub sso_url: String, pub slo_url: Option<Option<String>>, pub allow_idp_initiated: Option<bool>, pub name_id_policy: Option<SamlNameIdPolicyEnum>, pub binding_type: Option<BindingTypeEnum>, pub verification_kp: Option<Option<Uuid>>, pub signing_kp: Option<Option<Uuid>>, pub digest_algorithm: Option<DigestAlgorithmEnum>, pub signature_algorithm: Option<SignatureAlgorithmEnum>, pub temporary_user_delete_after: Option<String>, pub encryption_kp: Option<Option<Uuid>>, pub signed_assertion: Option<bool>, pub signed_response: Option<bool>,
}
SamlSource : SAMLSource Serializer

Fields

pk: Uuidname: String

Source’s display Name.

slug: String

Internal source name, used in URLs.

enabled: Option<bool>promoted: Option<bool>

When enabled, this source will be displayed as a prominent button on the login page, instead of a small icon.

authentication_flow: Option<Option<Uuid>>

Flow to use when authenticating existing users.

enrollment_flow: Option<Option<Uuid>>

Flow to use when enrolling new users.

user_property_mappings: Option<Vec<Uuid>>group_property_mappings: Option<Vec<Uuid>>component: String

Get object component so that we know how to edit the object

verbose_name: String

Return object’s verbose_name

verbose_name_plural: String

Return object’s plural verbose_name

meta_model_name: String

Return internal model name

policy_engine_mode: Option<PolicyEngineMode>user_matching_mode: Option<UserMatchingModeEnum>

How the source determines if an existing user should be authenticated or a new user enrolled.

managed: Option<String>

Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.

user_path_template: Option<String>icon: Option<String>icon_url: Stringicon_themed_urls: Option<ThemedUrls>group_matching_mode: Option<GroupMatchingModeEnum>

How the source determines if an existing group should be used or a new group created.

pre_authentication_flow: Uuid

Flow used before authentication.

issuer: Option<String>

Also known as Entity ID. Defaults the Metadata URL.

sso_url: String

URL that the initial Login request is sent to.

slo_url: Option<Option<String>>

Optional URL if your IDP supports Single-Logout.

allow_idp_initiated: Option<bool>

Allows authentication flows initiated by the IdP. This can be a security risk, as no validation of the request ID is done.

name_id_policy: Option<SamlNameIdPolicyEnum>

NameID Policy sent to the IdP. Can be unset, in which case no Policy is sent.

binding_type: Option<BindingTypeEnum>verification_kp: Option<Option<Uuid>>

When selected, incoming assertion’s Signatures will be validated against this certificate. To allow unsigned Requests, leave on default.

signing_kp: Option<Option<Uuid>>

Keypair used to sign outgoing Responses going to the Identity Provider.

digest_algorithm: Option<DigestAlgorithmEnum>signature_algorithm: Option<SignatureAlgorithmEnum>temporary_user_delete_after: Option<String>

Time offset when temporary users should be deleted. This only applies if your IDP uses the NameID Format ‘transient’, and the user doesn’t log out manually. (Format: hours=1;minutes=2;seconds=3).

encryption_kp: Option<Option<Uuid>>

When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.

signed_assertion: Option<bool>signed_response: Option<bool>

Implementations

Source

impl SamlSource

pub fn new( pk: Uuid, name: String, slug: String, component: String, verbose_name: String, verbose_name_plural: String, meta_model_name: String, managed: Option<String>, icon_url: String, icon_themed_urls: Option<ThemedUrls>, pre_authentication_flow: Uuid, sso_url: String, ) -> SamlSource

SAMLSource Serializer