ScimProviderRequest

Struct ScimProviderRequest 

pub struct ScimProviderRequest {
Show 16 fields pub name: String, pub property_mappings: Option<Vec<Uuid>>, pub property_mappings_group: Option<Vec<Uuid>>, pub url: String, pub verify_certificates: Option<bool>, pub token: Option<String>, pub auth_mode: Option<ScimAuthenticationModeEnum>, pub auth_oauth: Option<Option<Uuid>>, pub auth_oauth_params: Option<HashMap<String, Value>>, pub compatibility_mode: Option<CompatibilityModeEnum>, pub service_provider_config_cache_timeout: Option<String>, pub exclude_users_service_account: Option<bool>, pub sync_page_size: Option<u32>, pub sync_page_timeout: Option<String>, pub group_filters: Option<Vec<Uuid>>, pub dry_run: Option<bool>,
}
ScimProviderRequest : SCIMProvider Serializer

Fields

name: Stringproperty_mappings: Option<Vec<Uuid>>property_mappings_group: Option<Vec<Uuid>>

Property mappings used for group creation/updating.

url: String

Base URL to SCIM requests, usually ends in /v2

verify_certificates: Option<bool>token: Option<String>

Authentication token

auth_mode: Option<ScimAuthenticationModeEnum>auth_oauth: Option<Option<Uuid>>

OAuth Source used for authentication

auth_oauth_params: Option<HashMap<String, Value>>

Additional OAuth parameters, such as grant_type

compatibility_mode: Option<CompatibilityModeEnum>

Alter authentik behavior for vendor-specific SCIM implementations.

service_provider_config_cache_timeout: Option<String>

Cache duration for ServiceProviderConfig responses. Set minutes=0 to disable.

exclude_users_service_account: Option<bool>sync_page_size: Option<u32>

Controls the number of objects synced in a single task

sync_page_timeout: Option<String>

Timeout for synchronization of a single page

group_filters: Option<Vec<Uuid>>

Group filters used to define sync-scope for groups.

dry_run: Option<bool>

When enabled, provider will not modify or create objects in the remote system.

Implementations

Source

impl ScimProviderRequest

pub fn new(name: String, url: String) -> ScimProviderRequest

SCIMProvider Serializer