pub struct ScimSourcePropertyMappingRequest {
pub managed: Option<Option<String>>,
pub name: String,
pub expression: String,
}Expand description
ScimSourcePropertyMappingRequest : SCIMSourcePropertyMapping Serializer
Fields
managed: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Stringexpression: StringImplementations
Sourceimpl ScimSourcePropertyMappingRequest
impl ScimSourcePropertyMappingRequest
Sourcepub fn new(name: String, expression: String) -> ScimSourcePropertyMappingRequest
pub fn new(name: String, expression: String) -> ScimSourcePropertyMappingRequest
SCIMSourcePropertyMapping Serializer