pub struct Settings {Show 14 fields
pub avatars: Option<String>,
pub default_user_change_name: Option<bool>,
pub default_user_change_email: Option<bool>,
pub default_user_change_username: Option<bool>,
pub event_retention: Option<String>,
pub reputation_lower_limit: Option<i32>,
pub reputation_upper_limit: Option<u32>,
pub footer_links: Option<Option<Value>>,
pub gdpr_compliance: Option<bool>,
pub impersonation: Option<bool>,
pub impersonation_require_reason: Option<bool>,
pub default_token_duration: Option<String>,
pub default_token_length: Option<u32>,
pub flags: PatchedSettingsRequestFlags,
}Expand description
Settings : Settings Serializer
Fields
avatars: Option<String>Configure how authentik should show avatars for users.
default_user_change_name: Option<bool>Enable the ability for users to change their name.
default_user_change_email: Option<bool>Enable the ability for users to change their email address.
default_user_change_username: Option<bool>Enable the ability for users to change their username.
event_retention: Option<String>Events will be deleted after this duration.(Format: weeks=3;days=2;hours=3,seconds=2).
reputation_lower_limit: Option<i32>Reputation cannot decrease lower than this value. Zero or negative.
reputation_upper_limit: Option<u32>Reputation cannot increase higher than this value. Zero or positive.
gdpr_compliance: Option<bool>When enabled, all the events caused by a user will be deleted upon the user’s deletion.
impersonation: Option<bool>Globally enable/disable impersonation.
impersonation_require_reason: Option<bool>Require administrators to provide a reason for impersonating a user.
default_token_duration: Option<String>Default token duration
default_token_length: Option<u32>Default token length
flags: PatchedSettingsRequestFlagsImplementations