pub struct SourceStage {
pub pk: Uuid,
pub name: String,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub flow_set: Option<Vec<FlowSet>>,
pub source: Uuid,
pub resume_timeout: Option<String>,
}Expand description
SourceStage : SourceStage Serializer
Fields
pk: Uuidname: Stringcomponent: StringGet object type so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
flow_set: Option<Vec<FlowSet>>source: Uuidresume_timeout: Option<String>Amount of time a user can take to return from the source to continue the flow (Format: hours=-1;minutes=-2;seconds=-3)
Implementations