pub struct TelegramSourcePropertyMappingRequest {
pub managed: Option<Option<String>>,
pub name: String,
pub expression: String,
}Expand description
TelegramSourcePropertyMappingRequest : TelegramSourcePropertyMapping Serializer
Fields
managed: Option<Option<String>>Objects that are managed by authentik. These objects are created and updated automatically. This flag only indicates that an object can be overwritten by migrations. You can still modify the objects via the API, but expect changes to be overwritten in a later update.
name: Stringexpression: StringImplementations
Sourceimpl TelegramSourcePropertyMappingRequest
impl TelegramSourcePropertyMappingRequest
Sourcepub fn new(
name: String,
expression: String,
) -> TelegramSourcePropertyMappingRequest
pub fn new( name: String, expression: String, ) -> TelegramSourcePropertyMappingRequest
TelegramSourcePropertyMapping Serializer