pub struct WsFederationProviderRequest {Show 19 fields
pub name: String,
pub authentication_flow: Option<Option<Uuid>>,
pub authorization_flow: Uuid,
pub invalidation_flow: Uuid,
pub property_mappings: Option<Vec<Uuid>>,
pub reply_url: String,
pub wtrealm: String,
pub assertion_valid_not_before: Option<String>,
pub assertion_valid_not_on_or_after: Option<String>,
pub session_valid_not_on_or_after: Option<String>,
pub name_id_mapping: Option<Option<Uuid>>,
pub authn_context_class_ref_mapping: Option<Option<Uuid>>,
pub digest_algorithm: Option<DigestAlgorithmEnum>,
pub signature_algorithm: Option<SignatureAlgorithmEnum>,
pub signing_kp: Option<Option<Uuid>>,
pub encryption_kp: Option<Option<Uuid>>,
pub sign_assertion: Option<bool>,
pub sign_logout_request: Option<bool>,
pub default_name_id_policy: Option<SamlNameIdPolicyEnum>,
}Expand description
WsFederationProviderRequest : WSFederationProvider Serializer
Fields
name: Stringauthentication_flow: Option<Option<Uuid>>Flow used for authentication when the associated application is accessed by an un-authenticated user.
Flow used when authorizing this provider.
invalidation_flow: UuidFlow used ending the session from a provider.
property_mappings: Option<Vec<Uuid>>reply_url: Stringwtrealm: Stringassertion_valid_not_before: Option<String>Assertion valid not before current time + this value (Format: hours=-1;minutes=-2;seconds=-3).
assertion_valid_not_on_or_after: Option<String>Assertion not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
session_valid_not_on_or_after: Option<String>Session not valid on or after current time + this value (Format: hours=1;minutes=2;seconds=3).
name_id_mapping: Option<Option<Uuid>>Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be considered
authn_context_class_ref_mapping: Option<Option<Uuid>>Configure how the AuthnContextClassRef value will be created. When left empty, the AuthnContextClassRef will be set based on which authentication methods the user used to authenticate.
digest_algorithm: Option<DigestAlgorithmEnum>signature_algorithm: Option<SignatureAlgorithmEnum>signing_kp: Option<Option<Uuid>>Keypair used to sign outgoing Responses going to the Service Provider.
encryption_kp: Option<Option<Uuid>>When selected, incoming assertions are encrypted by the IdP using the public key of the encryption keypair. The assertion is decrypted by the SP using the the private key.
sign_assertion: Option<bool>sign_logout_request: Option<bool>default_name_id_policy: Option<SamlNameIdPolicyEnum>Implementations