pub struct CaptchaStage {Show 14 fields
pub pk: Uuid,
pub name: String,
pub component: String,
pub verbose_name: String,
pub verbose_name_plural: String,
pub meta_model_name: String,
pub flow_set: Vec<FlowSet>,
pub public_key: String,
pub js_url: Option<String>,
pub api_url: Option<String>,
pub interactive: Option<bool>,
pub score_min_threshold: Option<f64>,
pub score_max_threshold: Option<f64>,
pub error_on_invalid_score: Option<bool>,
}Expand description
CaptchaStage : CaptchaStage Serializer
Fields
pk: Uuidname: Stringcomponent: StringGet object type so that we know how to edit the object
verbose_name: StringReturn object’s verbose_name
verbose_name_plural: StringReturn object’s plural verbose_name
meta_model_name: StringReturn internal model name
flow_set: Vec<FlowSet>public_key: StringPublic key, acquired your captcha Provider.
js_url: Option<String>api_url: Option<String>interactive: Option<bool>score_min_threshold: Option<f64>score_max_threshold: Option<f64>error_on_invalid_score: Option<bool>When enabled and the received captcha score is outside of the given threshold, the stage will show an error message. When not enabled, the flow will continue, but the data from the captcha will be available in the context for policy decisions
Implementations