GoogleWorkspaceProvider

Struct GoogleWorkspaceProvider 

pub struct GoogleWorkspaceProvider {
Show 21 fields pub pk: i32, pub name: String, pub property_mappings: Option<Vec<Uuid>>, pub property_mappings_group: Option<Vec<Uuid>>, pub component: String, pub assigned_backchannel_application_slug: Option<String>, pub assigned_backchannel_application_name: Option<String>, pub verbose_name: String, pub verbose_name_plural: String, pub meta_model_name: String, pub delegated_subject: String, pub credentials: HashMap<String, Value>, pub scopes: Option<String>, pub exclude_users_service_account: Option<bool>, pub filter_group: Option<Option<Uuid>>, pub user_delete_action: Option<OutgoingSyncDeleteAction>, pub group_delete_action: Option<OutgoingSyncDeleteAction>, pub default_group_email_domain: String, pub sync_page_size: Option<u32>, pub sync_page_timeout: Option<String>, pub dry_run: Option<bool>,
}
GoogleWorkspaceProvider : GoogleWorkspaceProvider Serializer

Fields

pk: i32name: Stringproperty_mappings: Option<Vec<Uuid>>property_mappings_group: Option<Vec<Uuid>>

Property mappings used for group creation/updating.

component: String

Get object component so that we know how to edit the object

assigned_backchannel_application_slug: Option<String>

Internal application name, used in URLs.

assigned_backchannel_application_name: Option<String>

Application’s display Name.

verbose_name: String

Return object’s verbose_name

verbose_name_plural: String

Return object’s plural verbose_name

meta_model_name: String

Return internal model name

delegated_subject: Stringcredentials: HashMap<String, Value>scopes: Option<String>exclude_users_service_account: Option<bool>filter_group: Option<Option<Uuid>>user_delete_action: Option<OutgoingSyncDeleteAction>group_delete_action: Option<OutgoingSyncDeleteAction>default_group_email_domain: Stringsync_page_size: Option<u32>

Controls the number of objects synced in a single task

sync_page_timeout: Option<String>

Timeout for synchronization of a single page

dry_run: Option<bool>

When enabled, provider will not modify or create objects in the remote system.

Implementations

Source

impl GoogleWorkspaceProvider

pub fn new( pk: i32, name: String, component: String, assigned_backchannel_application_slug: Option<String>, assigned_backchannel_application_name: Option<String>, verbose_name: String, verbose_name_plural: String, meta_model_name: String, delegated_subject: String, credentials: HashMap<String, Value>, default_group_email_domain: String, ) -> GoogleWorkspaceProvider

GoogleWorkspaceProvider Serializer