pub struct LifecycleRule {Show 14 fields
pub id: Uuid,
pub name: String,
pub content_type: ContentTypeEnum,
pub object_id: Option<Option<String>>,
pub interval: Option<String>,
pub grace_period: Option<String>,
pub reviewer_groups: Option<Vec<Uuid>>,
pub reviewer_groups_obj: Vec<ReviewerGroup>,
pub min_reviewers: Option<u16>,
pub min_reviewers_is_per_group: Option<bool>,
pub reviewers: Vec<Uuid>,
pub reviewers_obj: Vec<ReviewerUser>,
pub notification_transports: Option<Vec<Uuid>>,
pub target_verbose: String,
}Expand description
LifecycleRule : Mixin to validate that a valid enterprise license exists before allowing to save the object
Fields
id: Uuidname: Stringcontent_type: ContentTypeEnumobject_id: Option<Option<String>>interval: Option<String>grace_period: Option<String>reviewer_groups: Option<Vec<Uuid>>reviewer_groups_obj: Vec<ReviewerGroup>min_reviewers: Option<u16>min_reviewers_is_per_group: Option<bool>reviewers: Vec<Uuid>reviewers_obj: Vec<ReviewerUser>notification_transports: Option<Vec<Uuid>>Select which transports should be used to notify the reviewers. If none are selected, the notification will only be shown in the authentik UI.
target_verbose: StringImplementations
Sourceimpl LifecycleRule
impl LifecycleRule
Sourcepub fn new(
id: Uuid,
name: String,
content_type: ContentTypeEnum,
reviewer_groups_obj: Vec<ReviewerGroup>,
reviewers: Vec<Uuid>,
reviewers_obj: Vec<ReviewerUser>,
target_verbose: String,
) -> LifecycleRule
pub fn new( id: Uuid, name: String, content_type: ContentTypeEnum, reviewer_groups_obj: Vec<ReviewerGroup>, reviewers: Vec<Uuid>, reviewers_obj: Vec<ReviewerUser>, target_verbose: String, ) -> LifecycleRule
Mixin to validate that a valid enterprise license exists before allowing to save the object